pub struct Block {
pub size: Coord,
pub query_start: Coord,
pub reference_start: Coord,
}Expand description
One alignment block of a PSL record.
A PSL block is described by three parallel coordinate lists in the file
(blockSizes, qStarts, tStarts); a Block materializes one entry of
each. query_start/reference_start are stored exactly as they appear in
the file — i.e. in reverse-complement coordinates when the corresponding
strand is -. Use crate::Psl::query_block_forward /
crate::Psl::reference_block_interval for forward-strand intervals.
Fields
size- Block length (in amino acids when the query is a protein)query_start- Start of the block on the query (rawqStarts[i])reference_start- Start of the block on the reference (rawtStarts[i])
Fields
size: Coordquery_start: Coordreference_start: CoordTrait Implementations
impl Copy for Block
impl Eq for Block
impl StructuralPartialEq for Block